@@ -1,15 +1,18 @@
-from __future__ import unicode_literals
-
 from unittest import TestCase
 
-from django import template
+from django.template import Context, Engine
 
 
 class CallableVariablesTests(TestCase):
 
+    @classmethod
+    def setUpClass(cls):
+        cls.engine = Engine()
+        super().setUpClass()
+
     def test_callable(self):
 
-        class Doodad(object):
+        class Doodad:
             def __init__(self, value):
                 self.num_calls = 0
                 self.value = value
@@ -19,12 +22,12 @@ class CallableVariablesTests(TestCase):
                 return {"the_value": self.value}
 
         my_doodad = Doodad(42)
-        c = template.Context({"my_doodad": my_doodad})
+        c = Context({"my_doodad": my_doodad})
 
         # We can't access ``my_doodad.value`` in the template, because
         # ``my_doodad.__call__`` will be invoked first, yielding a dictionary
         # without a key ``value``.
-        t = template.Template('{{ my_doodad.value }}')
+        t = self.engine.from_string('{{ my_doodad.value }}')
         self.assertEqual(t.render(c), '')
 
         # We can confirm that the doodad has been called
@@ -32,13 +35,13 @@ class CallableVariablesTests(TestCase):
 
         # But we can access keys on the dict that's returned
         # by ``__call__``, instead.
-        t = template.Template('{{ my_doodad.the_value }}')
+        t = self.engine.from_string('{{ my_doodad.the_value }}')
         self.assertEqual(t.render(c), '42')
         self.assertEqual(my_doodad.num_calls, 2)
 
     def test_alters_data(self):
 
-        class Doodad(object):
+        class Doodad:
             alters_data = True
 
             def __init__(self, value):
@@ -50,13 +53,13 @@ class CallableVariablesTests(TestCase):
                 return {"the_value": self.value}
 
         my_doodad = Doodad(42)
-        c = template.Context({"my_doodad": my_doodad})
+        c = Context({"my_doodad": my_doodad})
 
         # Since ``my_doodad.alters_data`` is True, the template system will not
         # try to call our doodad but will use string_if_invalid
-        t = template.Template('{{ my_doodad.value }}')
+        t = self.engine.from_string('{{ my_doodad.value }}')
         self.assertEqual(t.render(c), '')
-        t = template.Template('{{ my_doodad.the_value }}')
+        t = self.engine.from_string('{{ my_doodad.the_value }}')
         self.assertEqual(t.render(c), '')
 
         # Double-check that the object was really never called during the
@@ -65,7 +68,7 @@ class CallableVariablesTests(TestCase):
 
     def test_do_not_call(self):
 
-        class Doodad(object):
+        class Doodad:
             do_not_call_in_templates = True
 
             def __init__(self, value):
@@ -77,15 +80,15 @@ class CallableVariablesTests(TestCase):
                 return {"the_value": self.value}
 
         my_doodad = Doodad(42)
-        c = template.Context({"my_doodad": my_doodad})
+        c = Context({"my_doodad": my_doodad})
 
         # Since ``my_doodad.do_not_call_in_templates`` is True, the template
         # system will not try to call our doodad.  We can access its attributes
         # as normal, and we don't have access to the dict that it returns when
         # called.
-        t = template.Template('{{ my_doodad.value }}')
+        t = self.engine.from_string('{{ my_doodad.value }}')
         self.assertEqual(t.render(c), '42')
-        t = template.Template('{{ my_doodad.the_value }}')
+        t = self.engine.from_string('{{ my_doodad.the_value }}')
         self.assertEqual(t.render(c), '')
 
         # Double-check that the object was really never called during the
@@ -97,7 +100,7 @@ class CallableVariablesTests(TestCase):
         # ``alters_data`` attribute will not make any difference in the
         # template system's behavior.
 
-        class Doodad(object):
+        class Doodad:
             do_not_call_in_templates = True
             alters_data = True
 
@@ -110,11 +113,11 @@ class CallableVariablesTests(TestCase):
                 return {"the_value": self.value}
 
         my_doodad = Doodad(42)
-        c = template.Context({"my_doodad": my_doodad})
+        c = Context({"my_doodad": my_doodad})
 
-        t = template.Template('{{ my_doodad.value }}')
+        t = self.engine.from_string('{{ my_doodad.value }}')
         self.assertEqual(t.render(c), '42')
-        t = template.Template('{{ my_doodad.the_value }}')
+        t = self.engine.from_string('{{ my_doodad.the_value }}')
         self.assertEqual(t.render(c), '')
 
         # Double-check that the object was really never called during the
